"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var sectionRenderStrategy_1 = require("./sectionRenderStrategy");
var sectionGroupRenderStrategy_1 = require("./sectionGroupRenderStrategy");
var expandableNode_1 = require("./treeView/expandableNode");
var leafNode_1 = require("./treeView/leafNode");
var constants_1 = require("../constants");
var oneNoteItemUtils_1 = require("../oneNoteDataStructures/oneNoteItemUtils");
var notebookOpenedIcon_svg_1 = require("./icons/notebookOpenedIcon.svg");
var notebookClosedIcon_svg_1 = require("./icons/notebookClosedIcon.svg");
var chevron_svg_1 = require("./icons/chevron.svg");
var createNewSectionNode_1 = require("./createNewSection/createNewSectionNode");
var spinnerIcon_svg_1 = require("./icons/spinnerIcon.svg");
var strings_1 = require("../strings");
var NotebookRenderStrategy = /** @class */ (function () {
    function NotebookRenderStrategy(notebook, globals) {
        this.notebook = notebook;
        this.globals = globals;
        this.onClickBinded = function () { };
        this.onExpandBinded = this.onExpand.bind(this);
    }
    NotebookRenderStrategy.prototype.element = function () {
        return (React.createElement("div", { className: this.isSelected() ? 'picker-selectedItem picker-item notebook' : 'picker-item notebook', title: this.breadcrumbs() + '/' + this.notebook.name, onClick: this.onClick.bind(this) },
            React.createElement("div", { className: this.isExpanded() ? 'chevron-icon opened' : 'chevron-icon closed', onClick: this.onChevronClick.bind(this) },
                React.createElement(chevron_svg_1.ChevronSvg, null)),
            React.createElement("div", { className: 'picker-icon' }, this.isExpanded() ? React.createElement(notebookOpenedIcon_svg_1.NotebookOpenedIconSvg, null) : React.createElement(notebookClosedIcon_svg_1.NotebookClosedIconSvg, null)),
            React.createElement("div", { className: 'picker-label' },
                React.createElement("label", null, this.notebook.name))));
    };
    NotebookRenderStrategy.prototype.getName = function () {
        return this.notebook.name;
    };
    NotebookRenderStrategy.prototype.getId = function () {
        return this.notebook.id;
    };
    NotebookRenderStrategy.prototype.getChildren = function (childrenLevel) {
        var _this = this;
        if (this.notebook.apiHttpErrorMessage) {
            var errorString = this.notebook.apiHttpErrorMessage;
            return [
                React.createElement("li", { role: 'status', "aria-live": 'polite', "aria-label": errorString, className: 'progress-row' },
                    React.createElement("div", null, errorString))
            ];
        }
        if (!this.notebook.sections && !this.notebook.sectionGroups) {
            return [
                React.createElement("li", { className: 'progress-row' },
                    React.createElement(spinnerIcon_svg_1.SpinnerIconSvg, null))
            ];
        }
        var createNewSection = this.globals.callbacks.onSectionCreated || this.globals.shouldShowCreateEntityInputs ?
            [React.createElement(createNewSectionNode_1.CreateNewSectionNode, __assign({ key: this.notebook.id + 'createnewsectionnode' }, this.globals, { parent: this.notebook, parentIsNotebook: true, level: childrenLevel, 
                    // TODO (machiam) focusOnMount and tabbable logic will need to be reworked in the single notebook picker,
                    // for now we assume this is not top-level
                    focusOnMount: false, tabbable: false }))] :
            [];
        if (!this.notebook.sections || !this.notebook.sectionGroups) {
            return createNewSection.slice();
        }
        var setsize = this.notebook.sections.length + this.notebook.sectionGroups.length;
        var sectionGroupRenderStrategies = this.notebook.sectionGroups.map(function (sectionGroup) { return new sectionGroupRenderStrategy_1.SectionGroupRenderStrategy(sectionGroup, _this.globals); });
        var sectionGroups = sectionGroupRenderStrategies.map(function (renderStrategy, i) {
            return !!_this.globals.callbacks.onSectionSelected || !!_this.globals.callbacks.onPageSelected ?
                React.createElement(expandableNode_1.ExpandableNode, { expanded: renderStrategy.isExpanded(), node: renderStrategy, globals: _this.globals, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected(), selected: renderStrategy.isSelected(), setsize: setsize, posinset: _this.notebook.sections ? _this.notebook.sections.length + i + 1 : undefined }) :
                React.createElement(leafNode_1.LeafNode, { node: renderStrategy, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), globals: _this.globals, id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected() });
        });
        var sectionRenderStrategies = this.notebook.sections.map(function (section) { return new sectionRenderStrategy_1.SectionRenderStrategy(section, _this.globals); });
        var sections = sectionRenderStrategies.map(function (renderStrategy, i) {
            return !!_this.globals.callbacks.onPageSelected ?
                React.createElement(expandableNode_1.ExpandableNode, { expanded: renderStrategy.isExpanded(), node: renderStrategy, globals: _this.globals, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected() }) :
                React.createElement(leafNode_1.LeafNode, { node: renderStrategy, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), globals: _this.globals, id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected(), selected: renderStrategy.isSelected(), setsize: setsize, posinset: i + 1 });
        });
        return createNewSection.concat(sections, sectionGroups);
    };
    NotebookRenderStrategy.prototype.isExpanded = function () {
        return this.notebook.expanded;
    };
    NotebookRenderStrategy.prototype.isSelected = function () {
        return this.globals.selectedId === this.notebook.id;
    };
    NotebookRenderStrategy.prototype.isAriaSelected = function () {
        return this.globals.ariaSelectedId ? this.globals.ariaSelectedId === this.getId() : false;
    };
    NotebookRenderStrategy.prototype.expandNode = function (shouldExpand) {
        if (this.globals.callbacks.onSectionSelected || this.globals.callbacks.onPageSelected) {
            this.notebook.expanded = shouldExpand === undefined ? !this.notebook.expanded : shouldExpand;
        }
    };
    NotebookRenderStrategy.prototype.selectNode = function () {
        var onNotebookSelected = this.globals.callbacks.onNotebookSelected;
        if (!!onNotebookSelected) {
            onNotebookSelected(this.notebook, oneNoteItemUtils_1.OneNoteItemUtils.getAncestry(this.notebook));
        }
    };
    NotebookRenderStrategy.prototype.breadcrumbs = function () {
        var url = this.notebook.webUrl;
        var split = url.split('/');
        return split.slice(3, -1).map(decodeURIComponent).join('/');
    };
    NotebookRenderStrategy.prototype.onClick = function () {
        this.selectNode();
    };
    NotebookRenderStrategy.prototype.onChevronClick = function () {
        this.expandNode();
    };
    NotebookRenderStrategy.prototype.onExpand = function () {
        var _this = this;
        if (!this.notebook.sections && !this.notebook.sectionGroups && this.notebook.apiUrl && this.globals.oneNoteDataProvider) {
            this.globals.oneNoteDataProvider.getNotebookBySelfUrl(this.notebook.apiUrl, 5).then(function (notebook) {
                _this.notebook.sections = notebook.sections;
                _this.notebook.sectionGroups = notebook.sectionGroups;
            }).catch(function (apiError) {
                try {
                    _this.notebook.apiHttpErrorMessage = JSON.parse(apiError.response).error.message;
                }
                catch (error) {
                    _this.notebook.apiHttpErrorMessage = strings_1.Strings.getError(apiError.statusCode);
                }
            }).then(function () {
                if (_this.globals.callbacks.onNotebookInfoReturned) {
                    _this.globals.callbacks.onNotebookInfoReturned(_this.notebook);
                }
            });
        }
    };
    return NotebookRenderStrategy;
}());
exports.NotebookRenderStrategy = NotebookRenderStrategy;
//# sourceMappingURL=notebookRenderStrategy.js.map