"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var oneNoteItemUtils_1 = require("../../oneNoteDataStructures/oneNoteItemUtils");
var sectionIcon_svg_1 = require("../icons/sectionIcon.svg");
var constants_1 = require("../../constants");
var RecentSectionRenderStrategy = /** @class */ (function () {
    function RecentSectionRenderStrategy(section, globals) {
        this.section = section;
        this.globals = globals;
        this.onClickBinded = this.onClick.bind(this);
        // Add a recentSectionId constant to end of recent section id so we know it is recent section
        if (section.id.indexOf(constants_1.Constants.TreeView.recentSectionsId) < 0) {
            section.id = section.id + constants_1.Constants.TreeView.recentSectionsId;
        }
    }
    RecentSectionRenderStrategy.prototype.element = function () {
        return (React.createElement("div", { className: this.isSelected() ? 'picker-selectedItem section' : 'section', title: this.breadcrumbs() },
            React.createElement("div", { className: 'picker-icon' },
                React.createElement(sectionIcon_svg_1.SectionIconSvg, null)),
            React.createElement("div", { className: 'picker-label' },
                React.createElement("label", null, this.section.name),
                React.createElement("label", { className: 'parent' }, this.section.parentNotebookName ? this.section.parentNotebookName : ''))));
    };
    RecentSectionRenderStrategy.prototype.getName = function () {
        return this.section.name;
    };
    RecentSectionRenderStrategy.prototype.getId = function () {
        return this.section.id;
    };
    RecentSectionRenderStrategy.prototype.isSelected = function () {
        return this.globals.selectedId === this.getId();
    };
    RecentSectionRenderStrategy.prototype.isAriaSelected = function () {
        return this.globals.ariaSelectedId ? this.globals.ariaSelectedId === this.getId() : false;
    };
    RecentSectionRenderStrategy.prototype.onClick = function () {
        var onRecentSectionSelected = this.globals.callbacks.onRecentSectionSelected;
        if (!!onRecentSectionSelected) {
            onRecentSectionSelected(this.section, oneNoteItemUtils_1.OneNoteItemUtils.getAncestry(this.section));
        }
    };
    RecentSectionRenderStrategy.prototype.breadcrumbs = function () {
        if (this.section.webUrl) {
            var url = this.section.webUrl;
            // Get section group breadcrumbs from webUrl by parsing wd=target
            var target = decodeURIComponent(url).split('wd=target(//')[1];
            var parentSectionGroupBreadcrumbs = void 0;
            if (target) {
                parentSectionGroupBreadcrumbs = target.split("|/").slice(0, -2).join('/');
                parentSectionGroupBreadcrumbs = parentSectionGroupBreadcrumbs ? '/' + parentSectionGroupBreadcrumbs : '';
            }
            var split = url.split('/');
            return split.slice(3, -1).map(decodeURIComponent).join('/') +
                ("" + (this.section.parentNotebookName ? '/' + this.section.parentNotebookName : '') + parentSectionGroupBreadcrumbs + "/" + this.section.name);
        }
        return '';
    };
    return RecentSectionRenderStrategy;
}());
exports.RecentSectionRenderStrategy = RecentSectionRenderStrategy;
//# sourceMappingURL=recentSectionRenderStrategy.js.map