"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var sectionRenderStrategy_1 = require("./sectionRenderStrategy");
var expandableNode_1 = require("./treeView/expandableNode");
var leafNode_1 = require("./treeView/leafNode");
var constants_1 = require("../constants");
var sectionGroupIcon_svg_1 = require("./icons/sectionGroupIcon.svg");
var chevron_svg_1 = require("./icons/chevron.svg");
var createNewSectionNode_1 = require("./createNewSection/createNewSectionNode");
var SectionGroupRenderStrategy = /** @class */ (function () {
    function SectionGroupRenderStrategy(sectionGroup, globals) {
        this.sectionGroup = sectionGroup;
        this.globals = globals;
        this.onClickBinded = this.onClick.bind(this);
    }
    SectionGroupRenderStrategy.prototype.element = function () {
        return (React.createElement("div", { className: 'picker-item section-group', title: this.sectionGroup.name, onClick: this.onClick.bind(this) },
            React.createElement("div", { className: this.isExpanded() ? 'chevron-icon opened' : 'chevron-icon closed', onClick: this.onClick.bind(this) },
                React.createElement(chevron_svg_1.ChevronSvg, null)),
            React.createElement("div", { className: 'picker-icon' },
                React.createElement(sectionGroupIcon_svg_1.SectionGroupIconSvg, null)),
            React.createElement("div", { className: 'picker-label' },
                React.createElement("label", null, this.sectionGroup.name))));
    };
    SectionGroupRenderStrategy.prototype.getName = function () {
        return this.sectionGroup.name;
    };
    SectionGroupRenderStrategy.prototype.getId = function () {
        return this.sectionGroup.id;
    };
    SectionGroupRenderStrategy.prototype.getChildren = function (childrenLevel) {
        var _this = this;
        var createNewSection = this.globals.callbacks.onSectionCreated || this.globals.shouldShowCreateEntityInputs ?
            [React.createElement(createNewSectionNode_1.CreateNewSectionNode, __assign({ key: this.sectionGroup.id + 'createnewsectionnode' }, this.globals, { parent: this.sectionGroup, parentIsNotebook: false, level: childrenLevel, focusOnMount: false, tabbable: false }))] :
            [];
        var setsize = this.sectionGroup.sections.length + this.sectionGroup.sectionGroups.length;
        var sectionGroupRenderStrategies = this.sectionGroup.sectionGroups.map(function (sectionGroup) { return new SectionGroupRenderStrategy(sectionGroup, _this.globals); });
        var sectionGroups = sectionGroupRenderStrategies.map(function (renderStrategy, i) {
            return !!_this.globals.callbacks.onSectionSelected || !!_this.globals.callbacks.onPageSelected ?
                React.createElement(expandableNode_1.ExpandableNode, { expanded: renderStrategy.isExpanded(), node: renderStrategy, globals: _this.globals, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected(), selected: renderStrategy.isSelected(), setsize: setsize, posinset: _this.sectionGroup.sections.length + i + 1 }) :
                React.createElement(leafNode_1.LeafNode, { node: renderStrategy, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), globals: _this.globals, id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected() });
        });
        var sectionRenderStrategies = this.sectionGroup.sections.map(function (section) { return new sectionRenderStrategy_1.SectionRenderStrategy(section, _this.globals); });
        var sections = sectionRenderStrategies.map(function (renderStrategy, i) {
            return !!_this.globals.callbacks.onPageSelected ?
                React.createElement(expandableNode_1.ExpandableNode, { expanded: renderStrategy.isExpanded(), node: renderStrategy, globals: _this.globals, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected() }) :
                React.createElement(leafNode_1.LeafNode, { node: renderStrategy, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), globals: _this.globals, id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected(), selected: renderStrategy.isSelected(), setsize: setsize, posinset: i + 1 });
        });
        return createNewSection.concat(sections, sectionGroups);
    };
    SectionGroupRenderStrategy.prototype.isExpanded = function () {
        return this.sectionGroup.expanded;
    };
    SectionGroupRenderStrategy.prototype.isSelected = function () {
        return false;
    };
    SectionGroupRenderStrategy.prototype.isAriaSelected = function () {
        return this.globals.ariaSelectedId ? this.globals.ariaSelectedId === this.getId() : false;
    };
    SectionGroupRenderStrategy.prototype.expandNode = function (shouldExpand) {
        this.sectionGroup.expanded = shouldExpand == undefined ? !this.sectionGroup.expanded : shouldExpand;
    };
    SectionGroupRenderStrategy.prototype.selectNode = function () {
        this.expandNode();
    };
    SectionGroupRenderStrategy.prototype.onClick = function () {
        // No additional functionality
        this.expandNode();
    };
    return SectionGroupRenderStrategy;
}());
exports.SectionGroupRenderStrategy = SectionGroupRenderStrategy;
//# sourceMappingURL=sectionGroupRenderStrategy.js.map