"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var pageRenderStrategy_1 = require("./pageRenderStrategy");
var leafNode_1 = require("./treeView/leafNode");
var constants_1 = require("../constants");
var oneNoteItemUtils_1 = require("../oneNoteDataStructures/oneNoteItemUtils");
var sectionIcon_svg_1 = require("./icons/sectionIcon.svg");
var SectionRenderStrategy = /** @class */ (function () {
    function SectionRenderStrategy(section, globals) {
        this.section = section;
        this.globals = globals;
        this.onClickBinded = this.onClick.bind(this);
    }
    SectionRenderStrategy.prototype.element = function () {
        return (React.createElement("div", { className: this.isSelected() ? 'picker-selectedItem picker-item section' : 'picker-item section', title: this.section.name },
            React.createElement("div", { className: 'picker-icon' },
                React.createElement(sectionIcon_svg_1.SectionIconSvg, null)),
            React.createElement("div", { className: 'picker-label' },
                React.createElement("label", null, this.section.name))));
    };
    SectionRenderStrategy.prototype.getName = function () {
        return this.section.name;
    };
    SectionRenderStrategy.prototype.getId = function () {
        return this.section.id;
    };
    SectionRenderStrategy.prototype.getChildren = function (childrenLevel) {
        var _this = this;
        var pageRenderStrategies = this.section.pages && this.section.pages.map(function (page) { return new pageRenderStrategy_1.PageRenderStrategy(page, _this.globals); });
        var pages = pageRenderStrategies && pageRenderStrategies.map(function (renderStrategy) {
            return React.createElement(leafNode_1.LeafNode, { treeViewId: constants_1.Constants.TreeView.id, node: renderStrategy, globals: _this.globals, id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected(), selected: renderStrategy.isSelected() });
        });
        return pages || [];
    };
    SectionRenderStrategy.prototype.isExpanded = function () {
        return this.section.expanded;
    };
    SectionRenderStrategy.prototype.isSelected = function () {
        return this.globals.selectedId === this.section.id;
    };
    SectionRenderStrategy.prototype.isAriaSelected = function () {
        return this.globals.ariaSelectedId ? this.globals.ariaSelectedId === this.getId() : false;
    };
    SectionRenderStrategy.prototype.onClick = function () {
        var onSectionSelected = this.globals.callbacks.onSectionSelected;
        if (!!onSectionSelected) {
            onSectionSelected(this.section, oneNoteItemUtils_1.OneNoteItemUtils.getAncestry(this.section));
        }
    };
    return SectionRenderStrategy;
}());
exports.SectionRenderStrategy = SectionRenderStrategy;
//# sourceMappingURL=sectionRenderStrategy.js.map