"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var sectionRenderStrategy_1 = require("./sectionRenderStrategy");
var sectionGroupRenderStrategy_1 = require("./sectionGroupRenderStrategy");
var expandableNode_1 = require("./treeView/expandableNode");
var leafNode_1 = require("./treeView/leafNode");
var constants_1 = require("../constants");
var strings_1 = require("../strings");
var oneNoteItemUtils_1 = require("../oneNoteDataStructures/oneNoteItemUtils");
var notebookOpenedIcon_svg_1 = require("./icons/notebookOpenedIcon.svg");
var notebookClosedIcon_svg_1 = require("./icons/notebookClosedIcon.svg");
var spinnerIcon_svg_1 = require("./icons/spinnerIcon.svg");
var chevron_svg_1 = require("./icons/chevron.svg");
var createNewSectionNode_1 = require("./createNewSection/createNewSectionNode");
var SharedNotebookRenderStrategy = /** @class */ (function () {
    function SharedNotebookRenderStrategy(notebook, globals) {
        this.notebook = notebook;
        this.globals = globals;
        this.onClickBinded = function () { };
        this.onExpandBinded = this.onExpand.bind(this);
    }
    SharedNotebookRenderStrategy.prototype.element = function () {
        return (React.createElement("div", { className: this.isSelected() ? 'picker-selectedItem picker-item shared-notebook' : 'picker-item shared-notebook', title: this.breadcrumbs() + '/' + this.notebook.name, onClick: this.onClick.bind(this) },
            React.createElement("div", { className: this.isExpanded() ? 'chevron-icon opened' : 'chevron-icon closed', onClick: this.onChevronClick.bind(this) },
                React.createElement(chevron_svg_1.ChevronSvg, null)),
            React.createElement("div", { className: 'picker-icon' }, this.isExpanded() ? React.createElement(notebookOpenedIcon_svg_1.NotebookOpenedIconSvg, null) : React.createElement(notebookClosedIcon_svg_1.NotebookClosedIconSvg, null)),
            React.createElement("div", { className: 'picker-label' },
                React.createElement("label", null, this.notebook.name),
                React.createElement("label", { className: 'breadcrumbs' }, this.breadcrumbs())),
            React.createElement("div", { className: 'picker-shared-icon' },
                React.createElement("span", { "aria-hidden": 'true' }, strings_1.Strings.get('Shared')),
                React.createElement("i", { className: 'ms-Icon ms-Icon--People' }))));
    };
    SharedNotebookRenderStrategy.prototype.getId = function () {
        return this.notebook.id ? this.notebook.id : this.notebook.webUrl;
    };
    SharedNotebookRenderStrategy.prototype.getName = function () {
        return this.notebook.name;
    };
    SharedNotebookRenderStrategy.prototype.getChildren = function (childrenLevel) {
        var _this = this;
        if (this.notebook.apiHttpErrorMessage) {
            var errorString = this.notebook.apiHttpErrorMessage;
            return [
                React.createElement("li", { role: 'status', "aria-live": 'polite', "aria-label": errorString, className: 'progress-row' },
                    React.createElement("div", null, errorString))
            ];
        }
        if (!this.notebook.apiProperties) {
            return [
                React.createElement("li", { className: 'progress-row' },
                    React.createElement(spinnerIcon_svg_1.SpinnerIconSvg, null))
            ];
        }
        var createNewSection = this.globals.callbacks.onSectionCreated || this.globals.shouldShowCreateEntityInputs ?
            [React.createElement(createNewSectionNode_1.CreateNewSectionNode, __assign({ key: this.notebook.id + 'createnewsectionnode' }, this.globals, { parent: this.notebook, parentIsNotebook: true, level: childrenLevel, 
                    // TODO (machiam) focusOnMount and tabbable logic will need to be reworked in the single notebook picker,
                    // for now we assume this is not top-level
                    focusOnMount: false, tabbable: false }))] :
            [];
        var setsize = this.notebook.apiProperties.spSections.length + this.notebook.apiProperties.spSectionGroups.length;
        var sectionRenderStrategies = this.notebook.apiProperties.spSections.map(function (section) { return new sectionRenderStrategy_1.SectionRenderStrategy(section, _this.globals); });
        var sections = sectionRenderStrategies.map(function (renderStrategy, i) {
            return !!_this.globals.callbacks.onPageSelected ?
                React.createElement(expandableNode_1.ExpandableNode, { expanded: renderStrategy.isExpanded(), node: renderStrategy, globals: _this.globals, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected() }) :
                React.createElement(leafNode_1.LeafNode, { node: renderStrategy, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), globals: _this.globals, id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected(), selected: renderStrategy.isSelected(), setsize: setsize, posinset: i + 1 });
        });
        var sectionGroupRenderStrategies = this.notebook.apiProperties.spSectionGroups.map(function (sectionGroup) { return new sectionGroupRenderStrategy_1.SectionGroupRenderStrategy(sectionGroup, _this.globals); });
        var sectionGroups = sectionGroupRenderStrategies.map(function (renderStrategy, i) {
            return !!_this.globals.callbacks.onSectionSelected || !!_this.globals.callbacks.onPageSelected ?
                React.createElement(expandableNode_1.ExpandableNode, { expanded: renderStrategy.isExpanded(), node: renderStrategy, globals: _this.globals, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected(), selected: renderStrategy.isSelected(), setsize: setsize, posinset: _this.notebook.apiProperties.spSections.length + i + 1 }) :
                React.createElement(leafNode_1.LeafNode, { node: renderStrategy, treeViewId: constants_1.Constants.TreeView.id, key: renderStrategy.getId(), globals: _this.globals, id: renderStrategy.getId(), level: childrenLevel, ariaSelected: renderStrategy.isAriaSelected() });
        });
        return createNewSection.concat(sections, sectionGroups);
    };
    SharedNotebookRenderStrategy.prototype.isExpanded = function () {
        return this.notebook.expanded;
    };
    SharedNotebookRenderStrategy.prototype.isSelected = function () {
        return this.globals.selectedId === this.getId();
    };
    SharedNotebookRenderStrategy.prototype.isAriaSelected = function () {
        return this.globals.ariaSelectedId ? this.globals.ariaSelectedId === this.getId() : false;
    };
    SharedNotebookRenderStrategy.prototype.expandNode = function (shouldExpand) {
        if (this.globals.callbacks.onSectionSelected || this.globals.callbacks.onPageSelected) {
            this.notebook.expanded = shouldExpand === undefined ? !this.notebook.expanded : shouldExpand;
        }
    };
    SharedNotebookRenderStrategy.prototype.selectNode = function () {
        var onNotebookSelected = this.globals.callbacks.onNotebookSelected;
        if (!!onNotebookSelected) {
            onNotebookSelected(this.notebook, oneNoteItemUtils_1.OneNoteItemUtils.getAncestry(this.notebook));
        }
    };
    SharedNotebookRenderStrategy.prototype.onClick = function () {
        this.selectNode();
    };
    SharedNotebookRenderStrategy.prototype.onChevronClick = function () {
        this.expandNode();
    };
    SharedNotebookRenderStrategy.prototype.onExpand = function () {
        var _this = this;
        // Check if the picker is expandable
        if ((this.globals.callbacks.onSectionSelected || !!this.globals.callbacks.onPageSelected) &&
            !this.notebook.apiProperties && !this.notebook.startedLoading && this.globals.oneNoteDataProvider) {
            // This notebook was made known to us by GetRecentNotebooks, but we haven't
            // fetched any metadata or children info
            this.notebook.startedLoading = true;
            var depth = this.globals.notebookExpandDepth || 5;
            this.globals.oneNoteDataProvider.getSpNotebookProperties(this.notebook, depth, true).then(function (apiProperties) {
                if (!apiProperties) {
                    _this.notebook.apiHttpErrorMessage = strings_1.Strings.getError(404);
                    return;
                }
                _this.notebook.apiProperties = apiProperties;
                if (_this.globals.notebookListUpdater) {
                    _this.globals.notebookListUpdater.updateNotebookList([_this.notebook]);
                }
            }).catch(function (apiError) {
                try {
                    _this.notebook.apiHttpErrorMessage = JSON.parse(apiError.response).error.message;
                }
                catch (error) {
                    _this.notebook.apiHttpErrorMessage = strings_1.Strings.getError(apiError.statusCode);
                }
            }).then(function () {
                var onSharedNotebookInfoReturned = _this.globals.callbacks.onSharedNotebookInfoReturned;
                if (!!onSharedNotebookInfoReturned) {
                    onSharedNotebookInfoReturned(_this.notebook);
                }
            });
        }
    };
    SharedNotebookRenderStrategy.prototype.breadcrumbs = function () {
        var url = this.notebook.webUrl;
        var split = url.split('/');
        return split.slice(3, -1).map(decodeURIComponent).join('/');
    };
    return SharedNotebookRenderStrategy;
}());
exports.SharedNotebookRenderStrategy = SharedNotebookRenderStrategy;
//# sourceMappingURL=sharedNotebookRenderStrategy.js.map