"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var leafNode_1 = require("./leafNode");
var nameValidator_1 = require("../../nameValidator");
var constants_1 = require("../../constants");
/**
 * Functional component for creating a particular entity e.g., notebook. UI logic
 * should be passed in as props.
 */
var CreateEntityNode = /** @class */ (function (_super) {
    __extends(CreateEntityNode, _super);
    function CreateEntityNode(props) {
        var _this = _super.call(this, props) || this;
        _this.state = _this.defaultState();
        _this.setWrapperRef = _this.setWrapperRef.bind(_this);
        _this.setInputRefAndFocus = _this.setInputRefAndFocus.bind(_this);
        _this.handleClickOutside = _this.handleClickOutside.bind(_this);
        _this.handleEnterInput = _this.handleEnterInput.bind(_this);
        _this.resetAndFocus = _this.resetAndFocus.bind(_this);
        _this.onInputChange = _this.onInputChange.bind(_this);
        _this.onClick = _this.onClick.bind(_this);
        _this.setInputToNotStarted = _this.setInputToNotStarted.bind(_this);
        return _this;
    }
    CreateEntityNode.prototype.componentDidMount = function () {
        document.addEventListener('mousedown', this.handleClickOutside);
        this.componentIsMounted = true;
    };
    CreateEntityNode.prototype.componentWillUnmount = function () {
        document.removeEventListener('mousedown', this.handleClickOutside);
        this.componentIsMounted = false;
    };
    CreateEntityNode.prototype.handleClickOutside = function (event) {
        if (this.state.status === 'Input' && this.wrapperRef && !this.wrapperRef.contains(event.target)) {
            this.handleEnterInput();
        }
    };
    CreateEntityNode.prototype.handleEnterInput = function () {
        var _this = this;
        if (!this.state.nameInputValue) {
            // User aborted action by clicking out when the input box is empty/whitespace
            this.resetAndFocus();
        }
        if (!this.props.createEntity) {
            return;
        }
        var trimmedName = this.state.nameInputValue.trim();
        if (!trimmedName || nameValidator_1.NameValidator.validateNotebookName(trimmedName)) {
            // Don't fire off request or change state if user attempts to submit invalid name
            return;
        }
        this.setState({ status: 'InProgress' });
        this.props.createEntity(trimmedName).then(function () {
            if (_this.componentIsMounted) {
                _this.setState(_this.defaultState());
            }
        }).catch(function (error) {
            _this.setState({
                status: 'CreateError',
                lastError: error
            });
        });
    };
    CreateEntityNode.prototype.resetAndFocus = function () {
        this.setState(this.defaultState());
    };
    CreateEntityNode.prototype.defaultState = function () {
        return {
            status: 'NotStarted',
            nameInputValue: ''
        };
    };
    CreateEntityNode.prototype.render = function () {
        var focusOnMount = this.props.focusOnMount;
        var renderStrategy;
        switch (this.state.status) {
            case 'Input':
                renderStrategy = this.props.inputRenderStrategy(this.state.nameInputValue, this.handleEnterInput, this.onInputChange, this.setInputRefAndFocus, this.setInputToNotStarted);
                break;
            case 'CreateError':
                renderStrategy = this.props.createErrorRenderStrategy(this.state.lastError ? JSON.parse(this.state.lastError.response).error.message : '', this.state.nameInputValue, this.onInputChange, this.setInputToNotStarted);
                break;
            case 'InProgress':
                renderStrategy = this.props.inProgressRenderStrategy(this.state.nameInputValue);
                break;
            default:
                renderStrategy = this.props.notStartedRenderStrategy(this.onClick);
                break;
        }
        var props = {
            node: renderStrategy,
            treeViewId: constants_1.Constants.TreeView.id,
            id: renderStrategy.getId(),
            level: this.props.level,
            ariaSelected: renderStrategy.isAriaSelected(),
            tabbable: this.props.tabbable,
            focusOnMount: focusOnMount,
            globals: this.props,
        };
        return (React.createElement("div", { className: 'picker-input', ref: this.setWrapperRef },
            React.createElement(leafNode_1.LeafNode, __assign({}, props))));
    };
    CreateEntityNode.prototype.setWrapperRef = function (node) {
        this.wrapperRef = node;
    };
    CreateEntityNode.prototype.onClick = function () {
        if (this.state.status === 'NotStarted') {
            this.setState({
                status: 'Input'
            });
        }
    };
    CreateEntityNode.prototype.setInputToNotStarted = function () {
        if (this.state.status === 'Input' || this.state.status === "CreateError") {
            this.setState({
                status: 'NotStarted',
                nameInputValue: ''
            });
        }
    };
    CreateEntityNode.prototype.onInputChange = function (event) {
        this.setState({
            // We could have been in the error state, so explicitly set status
            status: 'Input',
            nameInputValue: event.target.value
        });
    };
    CreateEntityNode.prototype.setInputRefAndFocus = function (node) {
        this.inputRef = node;
        if (this.inputRef) {
            this.inputRef.focus();
        }
    };
    return CreateEntityNode;
}(React.Component));
exports.CreateEntityNode = CreateEntityNode;
//# sourceMappingURL=createEntityNode.js.map