/// <reference types="react" />
import * as React from 'react';
import { CommonNodeProps } from './commonNodeProps';
import { ExpandableNodeRenderStrategy } from './expandableNodeRenderStrategy';
export interface ExpandableNodeProps extends CommonNodeProps {
    expanded: boolean;
    node: ExpandableNodeRenderStrategy;
    onExpand?: (expanded: boolean) => void;
}
export interface ExpandableNodeState {
    expanded: boolean;
}
/**
 * Accessible TreeView parent node that supports keyboard navigation outlined in the
 * spec: https://www.w3.org/TR/wai-aria-practices-1.1/#TreeView
 * The design and interactability is defined by the injected RenderableExpandableNode
 * object, allowing for extensibility.
 */
export declare class ExpandableNode extends React.Component<ExpandableNodeProps, ExpandableNodeState> {
    constructor(props: ExpandableNodeProps);
    onClick(): void;
    onKeyDown(event: KeyboardEvent): void;
    componentDidMount(): void;
    private updateExpandedState(expanded);
    private level();
    private descendentId();
    render(): JSX.Element;
}
