"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var treeViewNavigationUtils_1 = require("./treeViewNavigationUtils");
/**
 * Accessible TreeView parent node that supports keyboard navigation outlined in the
 * spec: https://www.w3.org/TR/wai-aria-practices-1.1/#TreeView
 * The design and interactability is defined by the injected RenderableExpandableNode
 * object, allowing for extensibility.
 */
var ExpandableNode = /** @class */ (function (_super) {
    __extends(ExpandableNode, _super);
    function ExpandableNode(props) {
        var _this = _super.call(this, props) || this;
        _this.state = { expanded: props.expanded };
        return _this;
    }
    ExpandableNode.prototype.onClick = function () {
        var node = this.props.node;
        var nextExpandState = !this.state.expanded;
        this.updateExpandedState(nextExpandState);
        if (nextExpandState && node.onExpandBinded) {
            node.onExpandBinded();
        }
        node.onClickBinded();
        this.props.globals.callbacks.onAccessibleSelection(node.getId());
    };
    ExpandableNode.prototype.onKeyDown = function (event) {
        treeViewNavigationUtils_1.TreeViewNavigationUtils.normalizeKeyboardEventBehaviour(event);
        treeViewNavigationUtils_1.TreeViewNavigationUtils.handleMovementKeyboardEvent(this.props.id, this.props.treeViewId, event, this.props.globals.callbacks.onAccessibleSelection);
        switch (event.keyCode) {
            case 32:
                // Space
                this.onClick();
                if (this.props.node.selectNode) {
                    this.props.node.selectNode();
                }
                break;
            case 37:
                // Left arrow
                if (this.props.node.onCollapseBinded) {
                    this.props.node.onCollapseBinded();
                }
                this.updateExpandedState(false);
                if (this.props.node.expandNode) {
                    this.props.node.expandNode(false);
                }
                break;
            case 39:
                // Right arrow
                if (this.props.node.onExpandBinded) {
                    this.props.node.onExpandBinded();
                }
                this.updateExpandedState(true);
                if (this.props.node.expandNode) {
                    this.props.node.expandNode(true);
                }
                break;
            default:
                break;
        }
    };
    ExpandableNode.prototype.componentDidMount = function () {
        var _a = this.props, focusOnMount = _a.focusOnMount, id = _a.id;
        if (focusOnMount) {
            var self_1 = document.querySelector("[data-id='" + id + "']");
            self_1.focus();
        }
    };
    ExpandableNode.prototype.updateExpandedState = function (expanded) {
        this.setState({ expanded: expanded });
        if (this.props.onExpand) {
            this.props.onExpand(expanded);
        }
    };
    ExpandableNode.prototype.level = function () {
        return this.props.level || 1;
    };
    ExpandableNode.prototype.descendentId = function () {
        return this.props.treeViewId + this.props.id;
    };
    ExpandableNode.prototype.render = function () {
        return (React.createElement("li", null,
            React.createElement("a", { id: this.descendentId(), className: 'picker-row', onClick: this.onClick.bind(this), onKeyDown: this.onKeyDown.bind(this), "data-treeviewid": this.props.treeViewId, "data-id": this.props.id, tabIndex: this.props.ariaSelected ? 0 : -1, role: 'treeitem', "aria-labelledby": this.descendentId(), "aria-expanded": this.props.node.isExpanded(), "aria-selected": this.props.selected, "aria-level": this.level(), "aria-setsize": this.props.setsize, "aria-posinset": this.props.posinset }, this.props.children || this.props.node.element()),
            this.props.node.isExpanded() ?
                React.createElement("ul", { role: 'group' }, this.props.node.getChildren(this.level() + 1)) : undefined));
    };
    return ExpandableNode;
}(React.Component));
exports.ExpandableNode = ExpandableNode;
//# sourceMappingURL=expandableNode.js.map