/**
 * Provides utility methods for navigating TreeViews.
 */
export declare class TreeViewNavigationUtils {
    /**
     * Normalizes the keyboard event by preventing propogation and disabling
     * the scrolling effect on non-tab key presses.
     */
    static normalizeKeyboardEventBehaviour(event: KeyboardEvent): void;
    /**
     * In a TreeView, handles up, down, home, and end key presses to behave according
     * to the wai-aria spec defined in https://www.w3.org/TR/wai-aria-practices-1.1/#TreeView
     */
    static handleMovementKeyboardEvent(thisId: string, treeViewId: string, event: KeyboardEvent, onAccessibleSelected: (id: string) => void): void;
    /**
     * Given a non-zero integer offset, finds the navigatable within the same TreeView that is offsetted from the
     * element with the id attribute matching thisId.
     */
    static getNavigatableWithOffset(thisId: string, treeViewId: string, offset: number): HTMLElement | undefined;
    /**
     * Given a TreeView id, gets all navigatable (focusable) elements in that TreeView.
     */
    static getAllNavigatables(treeViewId: string): NodeListOf<HTMLElement>;
}
