"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var strings_1 = require("./strings");
var NameValidator = /** @class */ (function () {
    function NameValidator() {
    }
    NameValidator.validateNotebookName = function (name) {
        if (NameValidator.emptyName(name)) {
            return strings_1.Strings.get('Error.ValidateNotebookName.EmptyNotebookNameMessage');
        }
        if (NameValidator.startsOrEndsWithDot(name)) {
            return strings_1.Strings.get('Error.ValidateNotebookName.NotebookNameDotMessage');
        }
        if (NameValidator.nameTooLong(name)) {
            var message = strings_1.Strings.get('Error.ValidateNotebookName.LengthLimitMessage');
            return message.replace('{0}', '' + NameValidator.maxNotebookNameLength);
        }
        var matchesArray = name.match(this.InvalidNotebookNameCharactersRegex);
        if (matchesArray && matchesArray.length > 0) {
            var message = strings_1.Strings.get('Error.ValidateNotebookName.ContainsInvalidCharacterMessage');
            return message.replace('{0}', matchesArray[0]);
        }
        return undefined;
    };
    NameValidator.validateSectionName = function (name) {
        if (/^\./.test(name) || /\.$/.test(name)) {
            return strings_1.Strings.get('Error.ValidateSectionName.SectionNameDotMessage');
        }
        if (name.length > NameValidator.maxNotebookNameLength) {
            var message = strings_1.Strings.get('Error.ValidateSectionName.LengthLimitMessage');
            return message.replace('{0}', '' + NameValidator.maxNotebookNameLength);
        }
        var matchesArray = name.match(this.InvalidNotebookNameCharactersRegex);
        if (matchesArray && matchesArray.length > 0) {
            var message = strings_1.Strings.get('Error.ValidateSectionName.ContainsInvalidCharacterMessage');
            return message.replace('{0}', matchesArray[0]);
        }
        return undefined;
    };
    NameValidator.startsOrEndsWithDot = function (name) {
        return /^\./.test(name) || /\.$/.test(name);
    };
    NameValidator.nameTooLong = function (name) {
        return name.length > NameValidator.maxNotebookNameLength;
    };
    NameValidator.emptyName = function (name) {
        return name.length > 0 && name.trim().length === 0;
    };
    NameValidator.maxNotebookNameLength = 128;
    NameValidator.InvalidNotebookNameCharactersRegex = new RegExp('[' + String.fromCharCode(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 127) + '?*\\\\/:<>|"#%' + ']');
    return NameValidator;
}());
exports.NameValidator = NameValidator;
//# sourceMappingURL=nameValidator.js.map