import { Notebook } from './notebook';
import { Section } from './section';
import { Page } from './page';
/**
 * Responsible for updating the notebook list object in a controlled manner.
 * In particular, preserves expanded state. There is no guarantee that the
 * internal notebook list object * will be modified or replaced. Logic relying
 * on this class should use the getter as the most recent source of truth.
 */
export declare class NotebookListUpdater {
    private notebooks;
    constructor(initialNotebooks: Notebook[]);
    /**
     * Gets the notebook list
     */
    get(): Notebook[];
    /**
     * Updates the internal notebooks with a more recent version of the notebooks,
     * returned from the API.
     * @param apiNotebooks The API notebooks to update the internal notebooks with.
     */
    updateNotebookList(newNotebooks: Notebook[]): void;
    addNotebook(newNotebook: Notebook): void;
    addSection(newSection: Section): void;
    private preserveSectionParent(original, next);
    /**
     * Updates the internal notebooks' section with a more recent version of its
     * sections.
     * @param parentSectionId Parent section id.
     * @param apiPages The API pages to update the internal notebooks' matching section with.
     */
    updatePages(parentSectionId: string, newPages: Page[]): void;
    private getSectionRefFromNotebooks(sectionId, notebooks);
    private getSectionRefFromSectionParent(sectionId, sectionParent);
}
