"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Provides methods to transform data structures to equivalent data
 * structures used by the OneNotePicker.
 */
var OneNoteApiResponseTransformer = /** @class */ (function () {
    function OneNoteApiResponseTransformer() {
        this.defaultExpanded = false;
    }
    OneNoteApiResponseTransformer.prototype.transformNotebooks = function (notebookList) {
        var _this = this;
        return notebookList.map(function (notebook) { return _this.transformNotebook(notebook); });
    };
    OneNoteApiResponseTransformer.prototype.transformNotebook = function (notebook) {
        var _this = this;
        var transformed = {
            parent: undefined,
            id: notebook.id,
            name: notebook.name,
            expanded: this.defaultExpanded,
            sectionGroups: [],
            sections: [],
            apiUrl: notebook.self,
            // tslint:disable-next-line:no-any
            webUrl: notebook.links.oneNoteWebUrl.href,
            lastModifiedTime: notebook.lastModifiedTime
        };
        transformed.sectionGroups = notebook.sectionGroups ? notebook.sectionGroups.map(function (sg) { return _this.transformSectionGroup(sg, transformed); }) : undefined;
        transformed.sections = notebook.sections ? notebook.sections.map(function (section) { return _this.transformSection(section, transformed); }) : undefined;
        return transformed;
    };
    OneNoteApiResponseTransformer.prototype.transformSectionGroup = function (sectionGroup, parent) {
        var _this = this;
        var transformed = {
            parent: parent,
            id: sectionGroup.id,
            name: sectionGroup.name,
            expanded: this.defaultExpanded,
            sectionGroups: [],
            sections: [],
            apiUrl: sectionGroup.self,
        };
        transformed.sectionGroups = sectionGroup.sectionGroups ? sectionGroup.sectionGroups.map(function (sg) { return _this.transformSectionGroup(sg, transformed); }) : [];
        transformed.sections = sectionGroup.sections ? sectionGroup.sections.map(function (section) { return _this.transformSection(section, transformed); }) : [];
        return transformed;
    };
    OneNoteApiResponseTransformer.prototype.transformSection = function (section, parent) {
        var _this = this;
        // Pages may be undefined (e.g., in the getNotebooks call)
        // tslint:disable-next-line:no-any
        var sectionAsAny = section;
        var transformed = {
            parent: parent,
            id: section.id,
            name: section.name,
            expanded: this.defaultExpanded,
            pages: [],
            apiUrl: section.self,
            webUrl: sectionAsAny && sectionAsAny.links && sectionAsAny.links.oneNoteWebUrl && sectionAsAny.links.oneNoteWebUrl.href || undefined,
            clientUrl: sectionAsAny && sectionAsAny.links && sectionAsAny.links.oneNoteClientUrl && sectionAsAny.links.oneNoteClientUrl.href || undefined
        };
        transformed.pages = !!section.pages ? section.pages.map(function (page) { return _this.transformPage(page, transformed); }) : undefined;
        return transformed;
    };
    OneNoteApiResponseTransformer.prototype.transformPages = function (pageList, parent) {
        var _this = this;
        return pageList.map(function (page) { return _this.transformPage(page, parent); });
    };
    OneNoteApiResponseTransformer.prototype.transformPage = function (page, parent) {
        return {
            parent: parent,
            id: page.id,
            name: page.title,
            apiUrl: page.self,
            webUrl: page.links.oneNoteWebUrl.href
        };
    };
    return OneNoteApiResponseTransformer;
}());
exports.OneNoteApiResponseTransformer = OneNoteApiResponseTransformer;
//# sourceMappingURL=oneNoteApiResponseTransformer.js.map