import { Notebook } from './notebook';
import { OneNoteItem } from './oneNoteItem';
import { Section } from './section';
import { SectionGroup } from './sectionGroup';
export declare class OneNoteItemUtils {
    /**
     * Given the id of the OneNoteItem, and a notebook or sectionGroup list, returns
     * the OneNoteItem in the hierarchy that has the same id, or undefined
     * if it can't be found.
     */
    static find(sectionParents: (Notebook | SectionGroup)[], predicate: (item: OneNoteItem) => boolean): OneNoteItem | undefined;
    /**
     * Given the id of the OneNoteItem, and a section list, returns the OneNoteItem in
     * the hierarchy that has the same id, or undefined if it can't be found.
     */
    static findInSections(sections: Section[], predicate: (item: OneNoteItem) => boolean): OneNoteItem | undefined;
    /**
     * Given a predicate and a notebook hierarchy, expands to the first item that
     * satisfies the predicate if it exists in the hierarchy.
     */
    static expandTo(notebooks: Notebook[], predicate: (item: OneNoteItem) => boolean): void;
    /**
     * Performs a depth-first traversal on the item, pruning any of its child section groups
     * if they do not have a descendent section, and returning true if this item has at least
     * one descendent section; false otherwise.
     */
    static prune(root: Notebook | SectionGroup): boolean;
    /**
     * Given a OneNote item, returns a list representing the item's
     * ancestry, starting from the root notebook.
     */
    static getAncestry(item: OneNoteItem): OneNoteItem[];
}
