"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var polyfills_1 = require("../polyfills");
polyfills_1.Polyfills.find();
var OneNoteItemUtils = /** @class */ (function () {
    function OneNoteItemUtils() {
    }
    /**
     * Given the id of the OneNoteItem, and a notebook or sectionGroup list, returns
     * the OneNoteItem in the hierarchy that has the same id, or undefined
     * if it can't be found.
     */
    OneNoteItemUtils.find = function (sectionParents, predicate) {
        var findResult = sectionParents.find(predicate);
        if (!!findResult) {
            return findResult;
        }
        for (var i = 0; i < sectionParents.length; i++) {
            // For shared notebook we need to look at api properties
            var sectionParent = sectionParents[i];
            var sectionParentNotebook = sectionParent;
            var sectionGroups = void 0;
            var sections = void 0;
            if (sectionParentNotebook.apiProperties) {
                sectionGroups = sectionParentNotebook.apiProperties.spSectionGroups;
                sections = sectionParentNotebook.apiProperties.spSections;
            }
            else {
                if (!sectionParent.sections || !sectionParent.sectionGroups) {
                    continue;
                }
                sectionGroups = sectionParent.sectionGroups;
                sections = sectionParent.sections;
            }
            findResult = OneNoteItemUtils.find(sectionGroups, predicate);
            if (!!findResult) {
                return findResult;
            }
            findResult = OneNoteItemUtils.findInSections(sections, predicate);
            if (!!findResult) {
                return findResult;
            }
        }
        return undefined;
    };
    /**
     * Given the id of the OneNoteItem, and a section list, returns the OneNoteItem in
     * the hierarchy that has the same id, or undefined if it can't be found.
     */
    OneNoteItemUtils.findInSections = function (sections, predicate) {
        var findResult = sections.find(predicate);
        if (!!findResult) {
            return findResult;
        }
        for (var i = 0; i < sections.length; i++) {
            var pages = sections[i].pages;
            if (!!pages) {
                findResult = pages.find(predicate);
                if (!!findResult) {
                    return findResult;
                }
            }
        }
        return undefined;
    };
    /**
     * Given a predicate and a notebook hierarchy, expands to the first item that
     * satisfies the predicate if it exists in the hierarchy.
     */
    OneNoteItemUtils.expandTo = function (notebooks, predicate) {
        var item = OneNoteItemUtils.find(notebooks, predicate);
        if (!!item) {
            var ancestry = OneNoteItemUtils.getAncestry(item);
            for (var i = 0; i < ancestry.length - 1; i++) {
                // We know everything until the last item has to be one of these three types, regardless
                // of the item itself, as they have to be parents
                var expandable = ancestry[i];
                expandable.expanded = true;
            }
        }
    };
    /**
     * Performs a depth-first traversal on the item, pruning any of its child section groups
     * if they do not have a descendent section, and returning true if this item has at least
     * one descendent section; false otherwise.
     */
    OneNoteItemUtils.prune = function (root) {
        if (!root.sections || !root.sectionGroups) {
            return false;
        }
        root.sectionGroups = root.sectionGroups.filter(OneNoteItemUtils.prune);
        return root.sectionGroups.length > 0 || root.sections.length > 0;
    };
    /**
     * Given a OneNote item, returns a list representing the item's
     * ancestry, starting from the root notebook.
     */
    OneNoteItemUtils.getAncestry = function (item) {
        var current = item;
        var ancestry = [current];
        while (!!current.parent) {
            current = current.parent;
            ancestry.unshift(current);
        }
        return ancestry;
    };
    return OneNoteItemUtils;
}());
exports.OneNoteItemUtils = OneNoteItemUtils;
//# sourceMappingURL=oneNoteItemUtils.js.map